@@ -1,8 +1,19 @@
 /* $ID: matrix.c, last updated 2020-08-08, F.Osorio */
 
 #include "base.h"
+#include "utils.h"
 #include "matrix.h"
 
+void
+equilibrate(double *x, int *ldx, int *nrow, int *ncol, double *scales, double *condition, int *job)
+{ /* columns equilibration of a rectangular matrix */
+  int info = 0;
+
+  F77_CALL(equilibrate_cols)(x, ldx, nrow, ncol, scales, condition, job, &info);
+  if (info)
+    error("equilibrate_cols gave code %d", info);
+}
+
 void
 mat2vech(double *x, int *ldx, int *n, double *y)
 { /* y <- vech(x) */
@@ -15,10 +26,3 @@ mat2vech(double *x, int *ldx, int *n, double *y)
     }
   }
 }
-
-void
-hadamard_prod(double *x, double *y, int *n, double *prod)
-{ /* prod <- x * y */
-  for (int i = 0; i < *n; i++)
-    *prod++ = *x++ * *y++;
-}
